@@ -2,8 +2,7 @@ use serde::{Deserialize, Serialize};
 use solana_program::clock::UnixTimestamp;
 use tokio::select;
 use tokio::signal::unix::{signal, SignalKind};
-use tokio::sync::broadcast;
-use tokio::sync::mpsc::Sender;
+use tokio::sync::broadcast::{Receiver, Sender};
 use tracing::info;
 
 #[derive(Clone, Serialize, Deserialize)]
@@ -105,12 +104,12 @@ pub struct Shutdown {
     shutdown: bool,
 
     /// The receive half of the channel used to listen for shutdown.
-    notify: broadcast::Receiver<()>,
+    notify: Receiver<()>,
 }
 
 impl Shutdown {
     /// Create a new `Shutdown` backed by the given `broadcast::Receiver`.
-    pub fn new(notify: broadcast::Receiver<()>) -> Shutdown {
+    pub fn new(notify: Receiver<()>) -> Shutdown {
         Shutdown {
             shutdown: false,
             notify,
